<?php

namespace Drupal\web_host_metadata\Event;

use Drupal\Core\Cache\CacheableMetadata;
use Symfony\Contracts\EventDispatcher\Event;

/**
 * Defines a Web Host Metadata response event.
 */
class WebHostMetadataResponseEvent extends Event {

  /**
   * The XRD document.
   *
   * @var \XML_XRD
   */
  protected \XML_XRD $xrd;

  /**
   * The cacheable metadata.
   *
   * @var \Drupal\Core\Cache\CacheableMetadata
   */
  protected CacheableMetadata $responseCacheability;

  /**
   * Class constructor.
   */
  public function __construct(\XML_XRD $xrd, CacheableMetadata $response_cacheability) {
    $this->xrd = $xrd;
    $this->responseCacheability = $response_cacheability;
  }

  /**
   * The XRD document.
   *
   * @return \XML_XRD
   *   The XRD document.
   */
  public function getXrd(): \XML_XRD {
    return $this->xrd;
  }

  /**
   * The response cacheability.
   *
   * @return \Drupal\Core\Cache\CacheableMetadata
   *   The cacheable metadata.
   */
  public function getResponseCacheability(): CacheableMetadata {
    return $this->responseCacheability;
  }

}
